@@ -38,7 +38,16 @@ def main() -> int:  # noqa: C901
 
     subparsers.add_parser('update', help="Update all index files")
 
-    subparsers.add_parser('upgrade', help="Upgrade all plugins installed")
+    upgrade_parser = subparsers.add_parser('upgrade', help="Upgrade all plugins installed")
+    upgrade_parser.add_argument(
+        "-f",
+        "--force",
+        action="store_true",
+        help=(
+            "If specified, the upgrade will be forced for all plugins. Otherwise, it will be done only if "
+            "the version is different."
+        ),
+    )
 
     cache = subparsers.add_parser("cache", help="Look for a plugin in the cache")
     cache.add_argument("plugin_name", help="The plugin to look for")
@@ -50,8 +59,17 @@ def main() -> int:  # noqa: C901
     install.add_argument(
         "plugin_name",
         help=(
-            "The plugin to install, suffix '==version' is optional. The plugin might require quotes if there "
-            "is a space in its name."))
+            "The plugin to install, suffix '==version' is optional. The plugin might require quotes if "
+            "there is a space in its name."))
+    install.add_argument(
+        "-f",
+        "--force",
+        action="store_true",
+        help=(
+            "If specified, the install will be forced for the plugin, even if the version is already "
+            "installed."
+        ),
+    )
 
     args = parser.parse_args()
 
@@ -68,12 +86,10 @@ def main() -> int:  # noqa: C901
         # Except if the QGIS_PLUGINPATH is set
         plugin_path = Path(os.environ.get('QGIS_PLUGINPATH'))
 
-    if args.command in ("update", "remote", "cache", "search"):
-        # Remote only needed
+    if args.command in ("remote", "cache", "search"):
+        # Remote only needed, no QGIS version needed
         remote = Remote(plugin_path)
-        if args.command == "update":
-            exit_val = remote.update()
-        elif args.command == "remote":
+        if args.command == "remote":
             remote.print_list()
         elif args.command == "cache":
             latest = remote.latest(args.plugin_name)
@@ -86,6 +102,12 @@ def main() -> int:  # noqa: C901
             for result in results:
                 print(result)
 
+    elif args.command in ("update", ):
+        # Remote only needed, QGIS version needed
+        remote = Remote(plugin_path, qgis_server_version())
+        if args.command == "update":
+            exit_val = remote.update()
+
     elif args.command in ("remove", ):
         # Local needed only, without QGIS version
         plugins = LocalDirectory(plugin_path)
@@ -126,14 +148,19 @@ def main() -> int:  # noqa: C901
             exit_val = remote.install(
                 plugin_name=plugin_name,
                 version=plugin_version,
-                current_version=current_version
+                current_version=current_version,
+                force=args.force,
             )
 
         elif args.command == "upgrade":
             for folder in folders:
                 plugin_object = plugins.plugin_info(folder)
                 # Need to check version
-                result = remote.install(plugin_object.name, current_version=plugin_object.version)
+                result = remote.install(
+                    plugin_name=plugin_object.name,
+                    current_version=plugin_object.version,
+                    force=args.force,
+                )
                 if not result:
                     exit_val = False
 
