@@ -18,12 +18,6 @@ class TestRemote(unittest.TestCase):
             ["https://my.url/plugins.xml", "https://my.repo/plugins.xml"],
             self.remote.remote_list())
 
-    def test_similar_names(self):
-        """ Test about similar names in the XML file. """
-        self.remote = Remote(Path('fixtures/xml_files/lizmap'))
-        self.remote._parse_xml(Path('fixtures/xml_files/lizmap/lizmap.xml'), {})
-        self.assertListEqual(['Lizmap'], self.remote.similar_names('lizmap'))
-
     def test_plugin_name_with_space_and_tags(self):
         """ Test plugin with different name, using tags. """
         self.remote = Remote(Path('fixtures/xml_files/dataplotly'))
@@ -46,8 +40,8 @@ class TestRemote(unittest.TestCase):
 
         # Test the search
         self.assertListEqual([], self.remote.search("foo"))
-        self.assertListEqual(['Data Plotly'], self.remote.search("dataviz"))
-        self.assertListEqual(['Data Plotly'], self.remote.search("dataplotly"))
+        self.assertListEqual(['Data Plotly'], self.remote.search("dataviz", strict=False))
+        self.assertListEqual(['Data Plotly'], self.remote.search("dataplotly", strict=False))
 
     def test_search_with_space_in_name(self):
         """ Test Lizmap should give 2 values : Lizmap and 'Lizmap server'. """
@@ -72,7 +66,12 @@ class TestRemote(unittest.TestCase):
         )
 
         # Test the search
-        self.assertListEqual(['Lizmap', 'Lizmap server'], self.remote.search("lizmap"))
+        self.assertListEqual(['Lizmap', 'Lizmap server'], self.remote.search("lizmap", strict=False))
+
+    def test_qgis_dev_version(self):
+        """ Test check QGIS dev version number. """
+        self.assertListEqual(["3", "22", "11"], Remote.check_qgis_dev_version('3.22.11'))
+        self.assertListEqual(["3", "24", "0"], Remote.check_qgis_dev_version('3.23.0'))
 
     @unittest.expectedFailure
     def test_latest_pgmetadata(self):
